@@ -1,3 +1,20 @@
+# Copyright (c) 2010 by Yaco Sistemas
+#
+# This file is part of Merengue.
+#
+# Merengue is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# Merengue is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with Merengue.  If not, see <http://www.gnu.org/licenses/>.
+
 from django import template
 
 from cmsutils.tag_utils import (get_args_and_kwargs,
@@ -24,13 +41,13 @@ class GetActionsNode(template.Node):
         actions = []
         registered_actions = RegisteredAction.objects.actives()
         for registered_action in registered_actions:
-            item_class = registered_action.get_registry_item_class()
-            if scope == 'site' and issubclass(item_class, SiteAction):
-                actions.append(item_class)
-            elif for_content and scope == 'content' and issubclass(item_class, ContentAction):
-                actions.append(item_class)
-            elif for_content and scope == 'user' and issubclass(item_class, UserAction):
-                actions.append(item_class)
+            item = registered_action.get_registry_item()
+            if scope == 'site' and isinstance(item, SiteAction):
+                actions.append(item)
+            elif for_content and scope == 'content' and isinstance(item, ContentAction):
+                actions.append(item)
+            elif for_content and scope == 'user' and isinstance(item, UserAction):
+                actions.append(item)
         context[self.as_var] = actions
         return u''
 
@@ -64,10 +81,10 @@ class ActionURLNode(template.Node):
         action = self.action.resolve(context)
         action_link = None
         if content_or_user:
-            if action.has_action(content_or_user):
+            if action.has_action(request, content_or_user):
                 action_link = action.get_url(request, content_or_user)
         else:
-            if action.has_action():
+            if action.has_action(request):
                 action_link = action.get_url(request)
         context[self.variable_context] = action_link
         return ''
