@@ -22,6 +22,7 @@ from django import template
 from django.conf import settings
 from django.contrib import messages
 from django.core.urlresolvers import reverse
+from django.core.exceptions import FieldError
 from django.db import models, router
 from django.db.models import Q
 
@@ -866,6 +867,8 @@ class BaseContentAdmin(BaseOrderableAdmin, WorkflowBatchActionProvider, Permissi
 
     def queryset(self, request):
         queryset = super(BaseContentAdmin, self).queryset(request)
+        if not perms_api.has_global_permission(request.user, 'edit'):
+            queryset = queryset.filter(Q(owners=request.user) | Q(sections__owners=request.user))
         return queryset.select_related("workflow_status")
 
     def add_owners(self, request, queryset, owners):
@@ -925,6 +928,9 @@ class BaseContentAdmin(BaseOrderableAdmin, WorkflowBatchActionProvider, Permissi
                 for sel_obj in selected_objs:
                     if not self.has_change_permission(request, sel_obj):
                         return False
+            else:
+                return (perms_api.has_global_permission(request.user, 'edit') or
+                        self.has_modeladminview_permission(request))
         return perms_api.has_global_permission(request.user, 'edit')
 
     def has_delete_permission(self, request, obj=None):
@@ -953,6 +959,17 @@ class BaseContentAdmin(BaseOrderableAdmin, WorkflowBatchActionProvider, Permissi
         """
         return super(BaseContentAdmin, self).has_change_permission(request, None)
 
+    def has_modeladminview_permission(self, request):
+        check_section_owner = False
+        if hasattr(self.model, 'sections'):
+            try:
+                check_section_owner = bool(self.model._default_manager.filter(sections__owners=request.user))
+                if not check_section_owner:
+                    check_section_owner = bool(request.user.contents_owned.filter(class_name='microsite'))  # Force check if the user is owner of a microsite
+            except FieldError:
+                pass
+        return check_section_owner or bool(self.model._default_manager.filter(owners=request.user))
+
     def get_readonly_fields(self, request, obj=None):
         """
         Overrides Django admin behaviour for adding non changeable fields support
@@ -1384,7 +1401,7 @@ class BaseOrderableInlines(admin.ModelAdmin):
 
 class OrderableRelatedModelAdmin(RelatedModelAdmin):
     """
-    A model admin that can reorder related content.
+    A model admin that can reorder related content using a through model.
 
     Example use::
 
@@ -1453,6 +1470,63 @@ class OrderableRelatedModelAdmin(RelatedModelAdmin):
         raise NotImplementedError('You have to override this method')
 
 
+class SimpleOrderableRelatedModelAdmin(RelatedModelAdmin):
+    """
+    A model admin that can reorder related content.
+
+    Example use::
+
+      class Book(models.Model):
+          ...
+
+      class Page(models.Model):
+          book = models.ForeignKey(Book)
+          page_number = models.PositiveIntegerField()
+
+      class PageOrderableRelatedAdmin(SimpleOrderableRelatedModelAdmin):
+          model = Page
+          tool_name = 'pages'
+          tool_label = 'book pages'
+          related_field = 'books'
+          sortablefield = 'page_number'
+
+      >>> site.register_related(Page, PageOrderableRelatedAdmin, related_to=Book)
+    """
+    change_list_template = "admin/basecontent/related_sortable_change_list.html"
+    sortablefield = 'position'
+    sortablereverse = False
+
+    def __init__(self, *args, **kwargs):
+        super(SimpleOrderableRelatedModelAdmin, self).__init__(*args, **kwargs)
+        self.exclude = self.exclude or []
+        if self.sortablefield not in self.exclude:
+            self.exclude = [i for i in self.exclude] + [self.sortablefield]
+
+    def get_ordering(self):
+        """
+        Returns ordering by sortablefield
+        """
+        return (self.sortablefield, 'asc')
+
+    def changelist_view(self, request, extra_context=None, parent_model_admin=None, parent_object=None):
+        extra_context = self._update_extra_context(request, extra_context, parent_model_admin, parent_object)
+        if request.method == 'POST':
+            neworder_list = request.POST.get('neworder', None)
+            page = request.GET.get('p', 0)
+            if neworder_list is None:
+                return super(SimpleOrderableRelatedModelAdmin, self).changelist_view(request, extra_context, parent_model_admin, parent_object)
+            neworder_list = neworder_list.split(',')
+            if self.sortablereverse:
+                neworder_list.reverse()
+            items = self.queryset(request).filter(id__in=neworder_list)
+            for item in items:
+                neworder = neworder_list.index(unicode(item.id)) + (int(page) * 50)
+                setattr(item, self.sortablefield, neworder)
+                item.save()
+
+        return super(SimpleOrderableRelatedModelAdmin, self).changelist_view(request, extra_context, parent_model_admin, parent_object)
+
+
 class PermissionRelatedAdmin(RelatedModelAdmin, PermissionAdmin):
     """
     Model admin for permissions related to a managed content
