@@ -22,7 +22,7 @@ from django.contrib.admin import ModelAdmin
 from django.contrib.admin.sites import AdminSite as DjangoAdminSite
 from django.contrib.admin.sites import AlreadyRegistered
 from django.contrib.contenttypes.models import ContentType
-from django.core.exceptions import PermissionDenied, ObjectDoesNotExist
+from django.core.exceptions import ObjectDoesNotExist
 from django.core.urlresolvers import reverse
 from django.conf import settings
 from django.db.models.base import ModelBase
@@ -35,9 +35,10 @@ from django.utils.text import capfirst
 from django.utils.translation import ugettext as _
 from django.views.decorators.cache import never_cache
 
-from merengue.base.adminforms import UploadConfigForm, BackupForm
+from merengue.base.adminforms import UploadConfigForm
 from merengue.base.models import BaseContent
 from merengue.perms import utils as perms_api
+from merengue.base.actions import delete_selected
 
 OBJECT_ID_PREFIX = 'base_object_id_'
 MODEL_ADMIN_PREFIX = 'base_model_admin_'
@@ -48,6 +49,7 @@ class BaseAdminSite(DjangoAdminSite):
     index_template = 'admin/django_index.html'  # Django legacy index template
 
     def __init__(self, *args, **kwargs):
+        self._models_registry = {}
         self.apps_registered = []
         self.base_model_admins = {}
         self.base_object_ids = {}
@@ -55,6 +57,8 @@ class BaseAdminSite(DjangoAdminSite):
         self.related_registry = {}
         self.tools = {}
         super(BaseAdminSite, self).__init__(*args, **kwargs)
+        if hasattr(self, '_actions') and self._actions.get('delete_selected', None):
+            self._actions['delete_selected'] = delete_selected
 
     def admin_view(self, view, cacheable=False):
         def inner(request, *args, **kwargs):
@@ -122,6 +126,9 @@ class BaseAdminSite(DjangoAdminSite):
             url(r'^admin_redirect/(?P<content_type_id>\d+)/(?P<object_id>\d+)/(?P<extra_url>.*)$',
                 self.admin_view(self.admin_redirect),
                 name='admin_redirect'),
+            url(r'^models/$',
+                self.admin_view(self.models_index),
+                name='models_index'),
             url(r'^siteconfig/$',
                 self.admin_view(self.site_configuration),
                 name='site_configuration'),
@@ -174,6 +181,24 @@ class BaseAdminSite(DjangoAdminSite):
             # Instantiate the admin class to save in the registry
             self._registry[model] = admin_class(model, self)
 
+    def register_model(self, model_or_iterable, admin_class=None, **options):
+        """ Is a special register function which register a managed model.
+            This makes Merengue know the list of managed contents """
+        self.register(model_or_iterable, admin_class, **options)
+        if isinstance(model_or_iterable, ModelBase):
+            model_or_iterable = [model_or_iterable]
+        for model in model_or_iterable:
+            self._models_registry[model] = self._registry[model]
+
+    def unregister_model(self, model_or_iterable):
+        if isinstance(model_or_iterable, ModelBase):
+            model_or_iterable = [model_or_iterable]
+        for model in model_or_iterable:
+            if model in self._models_registry.keys():
+                del(self._models_registry[model])
+            if model in self._registry.keys():
+                del(self._registry[model])
+
     def admin_redirect(self, request, content_type_id, object_id, extra_url=''):
         """ redirect to content admin page or content related admin page in his section """
         try:
@@ -219,27 +244,42 @@ class BaseAdminSite(DjangoAdminSite):
         admin_prefix += '%s/%s/' % (model._meta.app_label, model._meta.module_name)
         return admin_prefix
 
+    def models_index(self, request, extra_context=None):
+        """ Index with all managed content types admin view """
+        model_list = []
+        for model, model_admin in self._models_registry.items():
+            model_dict = {
+                'name': capfirst(model._meta.verbose_name_plural),
+                'admin_url': reverse('admin:%s_%s_changelist' % (model._meta.app_label, model._meta.module_name)),
+                'model': model,
+            }
+            model_list.append(model_dict)
+            # Sort the models alphabetically
+            model_list.sort(key=lambda x: x['name'])
+        context = {
+            'title': _('Content types'),
+            'model_list': model_list,
+        }
+        context.update(extra_context or {})
+        context_instance = template.RequestContext(request, current_app=self.name)
+        return render_to_response(
+            'admin/model_index.html', context,
+            context_instance=context_instance,
+        )
+
     def site_configuration(self, request):
-        if not perms_api.can_manage_site(request.user):
-            raise PermissionDenied
+        perms_api.assert_manage_site(request.user)
         from merengue.utils import restore_config
+        form_configuration = UploadConfigForm()
         if request.method == 'POST':
             if request.POST.get('_submit_configuration', None):
                 form_configuration = UploadConfigForm(request.POST, request.FILES)
                 if form_configuration.is_valid():
                     restore_config(form_configuration.cleaned_data['zipfile'])
                     request.user.message_set.create(message=_('Settings saved successfully'))
-            elif request.POST.get('_submit_backup', None):
-                form_backup = BackupForm(request.POST, request.FILES)
-                if form_backup.is_valid():
-                    form_backup.save()
-                    request.user.message_set.create(message=_('Database created successfully'))
-        form_configuration = UploadConfigForm()
-        form_backup = BackupForm()
+                    form_configuration = UploadConfigForm()
         return render_to_response('admin/siteconfig.html',
-                                      {'form_configuration': form_configuration,
-                                       'form_backup': form_backup,
-                                      },
+                                      {'form_configuration': form_configuration},
                                       context_instance=RequestContext(request))
 
     def save_configuration(self, request):
@@ -293,7 +333,7 @@ class RelatedModelRegistrable(object):
         model_tools = self.tools.get(related_to, {})
 
         if tool_name in model_tools and admin_class != model_tools[tool_name].__class__:
-            raise Exception('Already registered a modeladmin with %s as tool_name' % tool_name)
+            raise AlreadyRegistered('Already registered a modeladmin with %s as tool_name' % tool_name)
 
         model_admin = model_tools.get(tool_name, admin_class(model_or_iterable, self))
         model_tools[tool_name] = model_admin
@@ -305,6 +345,28 @@ class RelatedModelRegistrable(object):
         self.related_registry[related_to] = base_model_registry
         self.tools[related_to] = model_tools
 
+    def unregister_related(self, model_or_iterable, admin_class=None, related_to=None, **options):
+
+        if not model_or_iterable or not admin_class or not related_to:
+            return
+        tool_name = admin_class and (getattr(admin_class, 'tool_name', None) or getattr(model_or_iterable._meta, 'module_name', None))
+        if not tool_name:
+            raise Exception('Can not unregister %s modeladmin without a tool_name' % admin_class.__name__)
+
+        model_tools = self.tools.get(related_to, {})
+        if tool_name in model_tools and admin_class != model_tools[tool_name].__class__:
+            raise AlreadyRegistered('Already registered a modeladmin with %s as tool_name' % tool_name)
+
+        model_admin = model_tools.get(tool_name, admin_class(model_or_iterable, self))
+        del model_tools[tool_name]
+        base_model_registry = self.related_registry.get(related_to, {})
+        related_modeladmins = base_model_registry.get(model_or_iterable, [])
+        if model_admin not in related_modeladmins:
+            related_modeladmins += [model_admin]
+        del base_model_registry[model_or_iterable]
+        self.related_registry[related_to] = base_model_registry
+        self.tools[related_to] = model_tools
+
 
 class AdminSite(BaseAdminSite, RelatedModelRegistrable):
 
@@ -341,11 +403,13 @@ class AdminSite(BaseAdminSite, RelatedModelRegistrable):
             if manage_plugin_content:
                 name = app_label.split('.')[1:]
                 name = name and name[0] or ''
+                config = get_plugin_config(name)
                 app_dict[app_label] = {
                     'name': name.title(),
                     'app_url': app_label + '/',
                     'has_module_perms': manage_plugin_content,
-                    'config': get_plugin_config(name),
+                    'description': getattr(config, 'description', None),
+                    'version': getattr(config, 'version', None),
                 }
 
         # Sort the apps alphabetically.
@@ -384,6 +448,7 @@ class AdminSite(BaseAdminSite, RelatedModelRegistrable):
 
 
 class PluginAdminSite(BaseAdminSite, RelatedModelRegistrable):
+    index_template = 'admin/index.html'  # Plugin aware index template
 
     def __init__(self, *args, **kwargs):
         self.main_site = kwargs.pop('main_admin_site', None)
