@@ -1,4 +1,4 @@
-# Copyright (c) 2010 by Yaco Sistemas <msaelices@yaco.es>
+# Copyright (c) 2010 by Yaco Sistemas
 #
 # This file is part of Merengue.
 #
@@ -17,18 +17,16 @@
 
 import BeautifulSoup
 import datetime
+import hashlib
 import re
 
 from django import forms
+from django.db import models
 from django.conf import settings
-from django.contrib.admin.widgets import RelatedFieldWidgetWrapper, AdminDateWidget
+from django.contrib.admin.widgets import RelatedFieldWidgetWrapper, AdminDateWidget, AdminSplitDateTime
 from django.core.urlresolvers import reverse, NoReverseMatch
-from django.forms.util import flatatt
-from django.forms.widgets import DateTimeInput
-from django.utils import datetime_safe
-from django.utils.encoding import force_unicode, smart_unicode
+from django.utils.encoding import smart_unicode
 from django.utils.safestring import mark_safe
-from django.utils.translation import get_language
 from django.utils.translation import ugettext as _
 
 from cmsutils.forms.widgets import TinyMCE, TINYMCE_JS
@@ -37,15 +35,17 @@ from cmsutils.forms.widgets import TinyMCE, TINYMCE_JS
 class ReadOnlyWidget(forms.Widget):
 
     def __init__(self, original_value, display_value):
+        if display_value is None:
+            display_value = original_value or u''
+        if isinstance(original_value, models.Model):
+            original_value = original_value.pk
         self.original_value = original_value
         self.display_value = display_value
 
         super(ReadOnlyWidget, self).__init__()
 
     def render(self, name, value, attrs=None):
-        if self.display_value is not None:
-            return unicode(self.display_value)
-        return unicode(self.original_value)
+        return unicode(self.display_value)
 
     def value_from_datadict(self, data, files, name):
         return self.original_value
@@ -53,6 +53,9 @@ class ReadOnlyWidget(forms.Widget):
 
 class CustomTinyMCE(TinyMCE):
 
+    to_add = {}
+    new_settings = []
+
     class Media:
         js = (TINYMCE_JS,
               '%smerengue/js/tiny_mce_internal_links/tiny_mce_internal_links.js' % settings.MEDIA_URL,
@@ -66,11 +69,21 @@ class CustomTinyMCE(TinyMCE):
         super(CustomTinyMCE, self).__init__(*args, **kwargs)
         self.mce_settings['width'] = '50%'
         self.mce_settings['height'] = '200px'
-        self.mce_settings['theme_advanced_buttons1'] = "undo,redo,separator,cut,copy,paste,pasteword,separator,bold,italic,underline,separator,justifyleft,justifycenter,justifyright,separator,bullist,numlist,outdent,indent,separator,preformatted_text,tablecontrols"
-        self.mce_settings['theme_advanced_buttons2'] = "styleselect,formatselect,fontselect,fontsizeselect,separator,forecolor,link,code,internal_links,iframes,image,file,removeformat"
+        self.mce_settings['theme_advanced_buttons1'] = """undo,redo,separator,cut,copy,paste,pasteword,separator,
+                                                         bold,italic,underline,separator,
+                                                         justifyleft,justifycenter,justifyright,justifyfull,separator,
+                                                         bullist,numlist,outdent,indent,separator,
+                                                         preformatted_text,tablecontrols"""
+        self.mce_settings['theme_advanced_buttons2'] = """styleselect,formatselect,fontselect,fontsizeselect,separator,
+                                                          forecolor,link,anchor,code,internal_links,iframes,image,file,removeformat"""
         self.mce_settings['theme_advanced_blockformats'] = 'h1,h2,h4,blockquote'
         self.mce_settings['plugins'] = "preview,paste,table,-internal_links,-iframes,-preformatted_text,-file"
         self.mce_settings['plugin_internal_links_base_url'] = '%smerengue/js/tiny_mce_internal_links/' % settings.MEDIA_URL
+
+        self.mce_settings['theme_advanced_statusbar_location'] = "bottom"
+        self.mce_settings['theme_advanced_resizing'] = True
+        self.mce_settings['theme_advanced_resize_horizontal'] = True
+
         try:
             self.mce_settings['plugin_internal_links_url'] = reverse('internal_links_search')
         except NoReverseMatch:
@@ -83,14 +96,40 @@ class CustomTinyMCE(TinyMCE):
         except NoReverseMatch:
             pass
         self.mce_settings['urlconverter_callback'] = "customUrlConverter"
-        content_css = settings.TINYMCE_EXTRA_MEDIA.get('css', [])
-        content_js = settings.TINYMCE_EXTRA_MEDIA.get('css', [])
+        content_css = [i for i in settings.TINYMCE_EXTRA_MEDIA.get('css', [])]
+        content_js = [i for i in settings.TINYMCE_EXTRA_MEDIA.get('css', [])]
         content_css.extend(["merengue/css/editorstyles.css"])
         content_css = ','.join(["%s%s" % (settings.MEDIA_URL, css) for css in content_css])
         self.mce_settings['content_css'] = content_css
         self.mce_settings['content_js'] = content_js
         self.mce_settings['extended_valid_elements'] = "hr[class|width|size|noshade],font[face|size|color|style],iframe[src|width|height|id|class|frameborder|border|marginwidth|marginheight|leftmargin|topmargin|allowtransparency|style],span[class|align|style],-table[border=0|cellspacing|cellpadding|width|height|class|align|summary|style|dir|id|lang|bgcolor|background|bordercolor],-tr[id|lang|dir|class|rowspan|width|height|align|valign|style|bgcolor|background|bordercolor],tbody[id|class],thead[id|class],tfoot[id|class],-td[id|lang|dir|class|colspan|rowspan|width|height|align|valign|style|bgcolor|background|bordercolor|scope],-th[id|lang|dir|class|colspan|rowspan|width|height|align|valign|style|scope],caption[id|lang|dir|class|style]"
 
+        self.extend_settings()
+
+    def extend_settings(self):
+        for key, value in self.to_add.items():
+            setting = self.mce_settings.get(key, None)
+            if setting:
+                value = [setting] + value
+            self.mce_settings[key] = ','.join(value)
+
+        for setting in self.new_settings:
+            self.mce_settings.update(setting)
+
+    @classmethod
+    def contribute_adding_to_setting(cls, setting_key, setting_value):
+        setting_list = cls.to_add.get(setting_key, [])
+        setting_list.append(setting_value)
+        cls.to_add[setting_key] = setting_list
+
+    @classmethod
+    def contribute_adding_new_setting(cls, setting_key, setting_value):
+        cls.new_settings.append({setting_key: setting_value})
+
+    @classmethod
+    def contribute_js(cls, js_url):
+        cls.Media.js += (js_url, )
+
     def render(self, name, value, attrs=None):
         urlconverter_callback = """<script type="text/javascript">
         function customUrlConverter(url, node, on_save) { return url; }
@@ -115,11 +154,11 @@ class CustomTinyMCE(TinyMCE):
         forbidden_tags = ('style', 'link', 'meta', 'script', 'xml', )
         for tag in soup.findAll():
             if tag.name in forbidden_tags:
-                tag.hidden=True
+                tag.hidden = True
             elif tag.name in unallowed_tags:
                 tag.name = 'span'
             else:
-                attr_todel=[]
+                attr_todel = []
                 for at, val in tag.attrs:
                     if at not in allowed_attrs:
                         attr_todel.append(at)
@@ -147,59 +186,35 @@ class AdminDateOfDateTimeWidget(AdminDateWidget):
         return super(AdminDateOfDateTimeWidget, self).render(name, value, attrs)
 
 
-class TranslatableInputDateWidget(DateTimeInput):
+class InputDateWidget(forms.DateInput):
 
     class Media:
-        js = ('/%s/jsi18n/' % settings.MERENGUE_URLS_PREFIX,
-              '%smerengue/js/dates_l10n/dates_l10n.js' % settings.MEDIA_URL,
-              '%sjs/core.js' % settings.ADMIN_MEDIA_PREFIX,
-              '%sjs/calendar.js' % settings.ADMIN_MEDIA_PREFIX,
-              '%smerengue/js/DateTimeShortcuts.js' % settings.MEDIA_URL,
-                )
-
+        js = (settings.MEDIA_URL + "admin/js/calendar.js",
+              settings.MEDIA_URL + "merengue/js/DateTimeShortcuts.js")
         css = {'all': ('%smerengue/css/event_calendar.css' % settings.MEDIA_URL, )}
 
-    def render(self, name, value, attrs=None):
-        if value is None:
-            value = ''
-        elif hasattr(value, 'strftime'):
-            value = datetime_safe.new_datetime(value)
-            value = value.strftime(self.format)
-        hidden_final_attrs = self.build_attrs(attrs, type='hidden', name=name)
-        final_attrs = self.build_attrs(attrs, type=self.input_type, name='visual-'+name)
-        final_attrs.update({'id': 'visual-' + final_attrs.get('id', name)})
-        final_attrs.update({'class': 'vDateField TranslatableInputDateWidget'})
-        if value != '':
-            # Only add the 'value' attribute if a value is non-empty.
-            hidden_final_attrs['value'] = force_unicode(value)
-        jsdates = '<script type="text/javascript" src="%smerengue/js/dates_l10n/dates_l10n_%s.js"></script>' % (settings.MEDIA_URL, get_language())
-        jsdates = '<script type="text/javascript" src="%smerengue/js/translatable_input_date_widget.js"></script>' % settings.MEDIA_URL
-        return mark_safe(u'%s<input%s /><input%s />' % (jsdates, flatatt(final_attrs), flatatt(hidden_final_attrs)))
+    def __init__(self, attrs={}, format=None):
+        super(InputDateWidget, self).__init__(attrs={'class': 'vDateField', 'size': '10'}, format=format)
 
 
 class InputTimeWidget(forms.TextInput):
 
     class Media:
-        js = (settings.ADMIN_MEDIA_PREFIX + "js/calendar.js",
-              '%smerengue/js/DateTimeShortcuts.js' % settings.MEDIA_URL)
+        js = (settings.MEDIA_URL + "admin/js/calendar.js",
+              settings.MEDIA_URL + "merengue/js/DateTimeShortcuts.js")
 
     def __init__(self, attrs={}):
         super(InputTimeWidget, self).__init__(attrs={'class': 'vTimeField', 'size': '8'})
 
 
-class TranslatableSplitDateTimeWidget(forms.SplitDateTimeWidget):
-    """
-    TranslatableSplitDateTimeWidget widget
-    """
+class SplitDateTimeWidget(AdminSplitDateTime):
 
     def __init__(self, attrs=None):
-        widgets = [TranslatableInputDateWidget, InputTimeWidget]
+        widgets = [InputDateWidget, InputTimeWidget, ]
+        # Note that we're calling MultiWidget, not SplitDateTimeWidget, because
+        # we want to define widgets.
         forms.MultiWidget.__init__(self, widgets, attrs)
 
-    def format_output(self, rendered_widgets):
-        return mark_safe(u'<p class="datetime">%s %s<br />%s %s</p>' % \
-            (_('Date:'), rendered_widgets[0], _('Time:'), rendered_widgets[1]))
-
 
 class RelatedBaseContentWidget(RelatedFieldWidgetWrapper):
 
@@ -208,6 +223,7 @@ class RelatedBaseContentWidget(RelatedFieldWidgetWrapper):
 
     def __init__(self, *args, **kwargs):
         self.hide_original_widget = kwargs.pop('hide_original_widget', True)
+        self.request = kwargs.pop('request', None)
         super(RelatedBaseContentWidget, self).__init__(*args, **kwargs)
 
     def render(self, name, value, *args, **kwargs):
@@ -229,14 +245,16 @@ class RelatedBaseContentWidget(RelatedFieldWidgetWrapper):
         else:
             output += super(RelatedBaseContentWidget, self).render(name, value, *args, **kwargs)
             output += u'<br />'
-        params=[]
+        params = []
         if getattr(self.widget, 'choices', None):
             for id, value in self.widget.choices:
                 if not isinstance(id, int):
                     continue
                 params.append(str(id))
-        if params:
-            params_str = '&id__in=%s' % ','.join(params)
+        if params and self.request:
+            widget_id = hashlib.sha1('%s_%s' % (self.request.META.get('PATH_INFO', ''), name)).hexdigest()
+            self.request.session[widget_id] = {'id__in': ','.join(params)}
+            params_str = '&widget_id=%s' % widget_id
         else:
             params_str = ''
 
@@ -268,21 +286,21 @@ if settings.USE_GIS:
             if geom_type.name == 'Point':
                 value_latitude = (value and value.get_y()) or ''
                 value_longitude = (value and value.get_x()) or ''
-                latitude = self._emule_widget_django('latitude', 'latitude', name, value_latitude)
-                longitude = self._emule_widget_django('longitude', 'longitude', name, value_longitude)
+                latitude = self._emule_widget_django('latitude', _('latitude'), name, value_latitude)
+                longitude = self._emule_widget_django('longitude', _('longitude'), name, value_longitude)
                 view_on_map = "<input id='view_on_map_%s' class='view_on_map' type='button' value='%s'/>" % (name, _('View on map'))
-                return mark_safe("%s %s %s %s"% (html, latitude, longitude, view_on_map))
+                return mark_safe("%s %s %s %s" % (html, latitude, longitude, view_on_map))
             return html
 
         def _emule_widget_django(self, label, sufix, name, value):
             label = _(label)
-            _id = "%s_%s" %(name, sufix)
+            _id = "%s_%s" % (name, sufix)
             _str = """<div class='form-row %s'>
                 <div>
                     <label for='id_%s'>%s:</label>
                     <input id='id_%s' class='change_%s' type='text' name='%s' value='%s'/>
                 </div>
-            </div>"""%(name, _id, label, _id, sufix, _id, value)
+            </div>""" % (name, _id, label, _id, sufix, _id, value)
             return _str
 
     class OpenLayersInlineAwareWidget(OpenLayersWidget):
