@@ -1,3 +1,20 @@
+# Copyright (c) 2010 by Yaco Sistemas
+#
+# This file is part of Merengue.
+#
+# Merengue is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# Merengue is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with Merengue.  If not, see <http://www.gnu.org/licenses/>.
+
 from django import forms
 from django.conf import settings
 from django.contrib import admin
@@ -9,17 +26,19 @@ from transmeta import get_real_fieldname_in_each_language
 
 from merengue.base.admin import (BaseContentAdmin, RelatedModelAdmin,
                                  BaseOrderableAdmin)
+from merengue.base.forms import BaseAdminModelForm
 from merengue.section.admin import SectionContentAdmin
 
 from merengue.base.models import BaseContent
 from merengue.section.models import BaseSection
+from merengue.collection.forms import (CollectionFilterForm, CollectionDisplayFilterForm,
+                                       CollectionAdminModelForm)
 from merengue.collection.models import (Collection, IncludeCollectionFilter,
                                         ExcludeCollectionFilter,
                                         CollectionDisplayField,
                                         CollectionDisplayFieldFilter,
                                         FeedCollection, FeedItem)
 from merengue.collection.utils import get_common_fields_no_language, get_common_fields
-from merengue.collection.forms import CollectionFilterForm, CollectionDisplayFilterForm
 
 
 DEFAULT_FILTERS = (
@@ -64,20 +83,34 @@ class IncludeCollectionFilterInline(CollectionFilterInline):
 
 
 class CollectionAdmin(BaseContentAdmin):
-    fieldsets = (
-        (_('Collection Basic Information'),
-            {'fields': get_real_fieldname_in_each_language('name') +\
-                       ['slug', ] +\
-                       get_real_fieldname_in_each_language('description') +\
-                       ['status', 'tags', 'meta_desc', 'commentable', 'owners']},
-            ),
-        (_('Collection Configuration'),
-            {'fields': ('content_types', 'group_by', 'order_by', 'limit', 'reverse_order', 'show_main_image', 'filtering_section')},
-            ),
-        )
     filter_horizontal = BaseContentAdmin.filter_horizontal + ('content_types', )
     inlines = [IncludeCollectionFilterInline, ExcludeCollectionFilterInline]
     change_form_template = 'collection/collection_admin_change_form.html'
+    form = CollectionAdminModelForm
+
+    def get_title_basic_info_fields(self, request, obj=None):
+        return _('Collection Basic Information')
+
+    def get_basic_info_fields(self, request, obj=None):
+        basic_info_fields = get_real_fieldname_in_each_language('name') + \
+                            ['slug', ] + get_real_fieldname_in_each_language('description') + \
+                            ['workflow_status', 'tags', 'meta_desc', 'commentable']
+        if request.user.is_superuser:
+            basic_info_fields.append('owners')
+        return basic_info_fields
+
+    def get_title_configurations_fields(self, request, obj=None):
+        return _('Collection Configuration')
+
+    def get_configurations_fields(self, request, obj=None):
+        return ['content_types', 'group_by', 'order_by', 'reverse_order', 'limit',
+                'show_main_image', 'filtering_section']
+
+    def get_fieldsets(self, request, obj=None):
+        return ((self.get_title_basic_info_fields(request, obj),
+                {'fields': self.get_basic_info_fields(request, obj)}),
+                (self.get_title_configurations_fields(request, obj),
+                {'fields': self.get_configurations_fields(request, obj)}),)
 
     def queryset(self, request):
         qs = super(CollectionAdmin, self).queryset(request)
@@ -104,7 +137,10 @@ class CollectionAdmin(BaseContentAdmin):
             if _seen is None:
                 _seen = set()
             try:
-                subs = cls.__subclasses__()
+                if issubclass(cls, BaseContent):
+                    subs = cls.get_subclasses()
+                else:
+                    subs = cls.__subclasses__()
             except TypeError:  # fails only when cls is type
                 subs = cls.__subclasses__(cls)
             for sub in subs:
@@ -122,6 +158,7 @@ class CollectionAdmin(BaseContentAdmin):
             for m in main_models:
                 if not m._meta.abstract:
                     types_id.append(ContentType.objects.get_for_model(m).id)
+            types_id.append(ContentType.objects.get_for_model(BaseContent).id)
             form.base_fields['content_types'].queryset = form.base_fields['content_types'].queryset.filter(id__in=types_id)
         default_fields = self.get_default_fields(obj, request)
         if default_fields:
@@ -136,6 +173,7 @@ class CollectionAdmin(BaseContentAdmin):
 class CollectionRelatedModelAdmin(SectionContentAdmin, CollectionAdmin):
     tool_name = 'collections'
     tool_label = _('collections')
+    change_form_template = CollectionAdmin.change_form_template
 
 
 class CollectionDisplayFieldFilterInline(admin.TabularInline):
@@ -152,7 +190,7 @@ class CollectionDisplayFieldFilterInline(admin.TabularInline):
 
 class CollectionDisplayFieldAdmin(RelatedModelAdmin, BaseOrderableAdmin):
     tool_name = 'display_fields'
-    tool_label = _('display fields')
+    tool_label = _('fields to display in the list')
     related_field = 'collection'
     sortablefield = 'field_order'
     ordering = ('field_order', )
@@ -193,7 +231,7 @@ class CollectionDisplayFieldAdmin(RelatedModelAdmin, BaseOrderableAdmin):
 
 class FeedItemDisplayFieldAdmin(CollectionDisplayFieldAdmin):
     tool_name = 'display_fields_in_item'
-    tool_label = _('full item fields')
+    tool_label = _('fields in the detail view of the object')
 
     def get_default_fields(self, obj):
         if not obj:
@@ -218,29 +256,29 @@ class FeedItemAdmin(RelatedModelAdmin):
     tool_name = 'items'
     tool_label = _('feed items')
     related_field = 'feed_collection'
+    exclude = ('owners', 'participants', 'adquire_global_permissions')
 
 
 class FeedCollectionAdmin(CollectionAdmin):
-    fieldsets = (
-        (_('Collection Basic Information'),
-            {'fields': get_real_fieldname_in_each_language('name') +\
-                       ['slug', ] +\
-                       get_real_fieldname_in_each_language('description') +\
-                       ['status', 'tags', 'meta_desc', 'commentable', 'owners']},
-            ),
-        (_('Collection Configuration'),
-            {'fields': ('feed_url', 'expire_seconds', 'remove_items', )},
-            ),
-        )
     change_form_inlines = [IncludeCollectionFilterInline, ExcludeCollectionFilterInline]
-    add_configuration_fields = ('feed_url', 'expire_seconds', 'remove_items', )
-    change_configuration_fields = ('feed_url', 'expire_seconds', 'remove_items', 'group_by', 'order_by', 'reverse_order')
+    form = BaseAdminModelForm
     item_fieldsets = (
         (_('Single Item Configuration'),
             {'fields': ('title_field', 'detailed_link', 'external_link', )},
             ),
         )
 
+    def get_fieldsets(self, request, obj=None):
+        fieldsets = super(FeedCollectionAdmin, self).get_fieldsets(request, obj)
+        if obj:
+            fieldsets = fieldsets + self.item_fieldsets
+        return fieldsets
+
+    def get_configurations_fields(self, request, obj=None):
+        if not obj:
+            return ['feed_url', 'expire_seconds', 'remove_items']
+        return ['feed_url', 'expire_seconds', 'remove_items', 'group_by', 'order_by', 'reverse_order']
+
     def queryset(self, request):
         return super(CollectionAdmin, self).queryset(request)
 
@@ -252,14 +290,10 @@ class FeedCollectionAdmin(CollectionAdmin):
 
     def add_view(self, *args, **kwargs):
         self.inline_instances = []
-        self.fieldsets[1][1]['fields'] = self.add_configuration_fields
-        self.fieldsets = self.fieldsets[:2]
         return super(FeedCollectionAdmin, self).add_view(*args, **kwargs)
 
     def change_view(self, *args, **kwargs):
         self.inline_instances = []
-        self.fieldsets[1][1]['fields'] = self.change_configuration_fields
-        self.fieldsets = self.fieldsets[:2] + self.item_fieldsets
         for inline_class in self.change_form_inlines:
             inline_instance = inline_class(self.model, self.admin_site)
             self.inline_instances.append(inline_instance)
@@ -276,9 +310,15 @@ class FeedCollectionAdmin(CollectionAdmin):
                 form.base_fields[i].widget = forms.Select(choices=default_fields)
         return form
 
+    def response_add(self, request, obj, post_url_continue='../%s/'):
+        if obj:
+            obj.perform_query(apply_options=True, force_update=True)
+            obj.save()
+        return super(FeedCollectionAdmin, self).response_add(request, obj, post_url_continue)
+
 
 class FeedCollectionRelatedModelAdmin(SectionContentAdmin, FeedCollectionAdmin):
-    tool_name = 'feed collections'
+    tool_name = 'feed_collections'
     tool_label = _('feed collections')
 
 
