@@ -1,8 +1,26 @@
+# Copyright (c) 2010 by Yaco Sistemas
+#
+# This file is part of Merengue.
+#
+# Merengue is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# Merengue is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with Merengue.  If not, see <http://www.gnu.org/licenses/>.
+
 from copy import copy
 
 from django.db.models import Q
 from django.db.models.manager import Manager
-from django.core.exceptions import FieldError
+from django.conf import settings
+from django.core.exceptions import FieldError, ObjectDoesNotExist
 from django.template import TemplateSyntaxError, Library, Node, Context
 from django.template.defaulttags import RegroupNode
 
@@ -85,7 +103,22 @@ class CollectionItemsNode(Node):
         items = collection.get_items(section)
         ignore_filters = request and request.GET.get('__ignore_filters', None)
         if not ignore_filters:
-            if request:
+            # This a code to smarsearch plugin
+            searcher_id = request.GET.get('__searcher', None)
+            searcher = None
+            if searcher_id and 'plugins.smartsearch' in settings.INSTALLED_APPS:
+                try:
+                    from plugins.smartsearch.models import Searcher
+                    searcher = Searcher.objects.get(pk=searcher_id)
+                except (ImportError, ObjectDoesNotExist):
+                    pass
+                if searcher:
+                    from autoreports.utils import pre_procession_request, filtering_from_request
+                    model = collection.get_first_parents_of_content_types()
+                    request_processing = pre_procession_request(request, model)
+                    filters, items = filtering_from_request(request_processing, items, searcher)
+            # Here end the code to smartsearch plugin
+            if not searcher and request:
                 items = self._filter_by_request(request, items)
             if context:
                 items = self._filter_by_context(context, items)
@@ -138,14 +171,16 @@ class CollectionItemsNode(Node):
     def render(self, context):
         collection = self.collection.resolve(context)
         if isinstance(collection, FeedCollection):
-            context.update({self.var_name: collection.get_items()})
+            items = collection.get_items()
+            if collection.limit:
+                items = items[:collection.limit]
+            context.update({self.var_name: items})
             return ''
         items = self._get_items(collection, context)
         context.update({self.var_name: items})
 
         group_by_attr = context.get('_group_by_collection',
                                     get_common_field_translated_name(collection, collection.group_by))
-        group_by_attr = get_common_field_translated_name(collection, collection.group_by)
         order_by_attr = context.get('_order_by_collection', None)
         can_reversed = False
         if not order_by_attr:
@@ -153,6 +188,9 @@ class CollectionItemsNode(Node):
             can_reversed = True
 
         if not group_by_attr and not order_by_attr:
+            if collection.limit:
+                items = items[:collection.limit]
+            context.update({self.var_name: items})
             return ''
         if not order_by_attr and group_by_attr:
             items = items.order_by(group_by_attr)
