@@ -5,7 +5,7 @@ from django.shortcuts import render_to_response
 from django.template import RequestContext
 from django.utils.translation import ugettext as _
 
-from cmsutils.log import send_info
+from merengue.base.log import send_info
 from merengue.perms.forms import AccessRequestForm
 
 
