@@ -31,7 +31,7 @@ from merengue.cache import invalidate_cache_for_path
 from merengue.perms.decorators import permission_required
 from merengue.perms.utils import MANAGE_CACHE_INVALIDATION_PERMISSION
 
-from cmsutils.log import send_info
+from merengue.base.log import send_info
 
 
 @never_cache
@@ -44,7 +44,8 @@ def login(request, redirect_field_name='next'):
 
 @never_cache
 def logout(request, template_name='registration/logged_out.html'):
-    response = auth_logout(request, next_page='/')
+    next_page = settings.LOGOUT_REDIRECT_URL or '/'
+    response = auth_logout(request, next_page=next_page)
     send_info(request, _("Thanks for your visit"))
     return response
 
