@@ -165,6 +165,12 @@ class SectionAdmin(BaseSectionAdmin):
         extra_context.update({'section_tools': section_tools})
         return super(SectionAdmin, self).changelist_view(request, extra_context)
 
+    def queryset(self, request, bypass_perms=False):
+        qs = super(BaseSectionAdmin, self).queryset(request)
+        if self.__class__.__name__ == 'SectionAdmin' and settings.ADMIN_PURE_SECTIONS:
+            qs = qs.filter(class_name='basesection')
+        return qs
+
 
 class SectionContentAdmin(OrderableRelatedModelAdmin):
     related_field = 'sections'
@@ -214,7 +220,7 @@ class CustomStyleRelatedModelAdmin(RelatedModelAdmin):
 
 
 class DocumentAdmin(BaseContentAdmin):
-    list_display = ('name', 'slug', 'workflow_status', )
+    list_display = ('__unicode__', 'slug', 'workflow_status', )
     html_fields = ('description', 'body', )
     prepopulated_fields = {'slug': (get_fallback_fieldname('name'), )}
     actions = BaseAdmin.actions + ['set_as_published', 'set_as_draft']
@@ -449,6 +455,8 @@ class BaseSectionMenuRelatedAdmin(MenuAdmin, RelatedModelAdmin):
     def save_model(self, request, obj, form, change):
         if not obj.parent:
             obj.parent = self.get_menu(request)
+            if hasattr(obj._mptt_meta, 'update_mptt_cached_fields'):
+                obj._mptt_meta.update_mptt_cached_fields(obj)
         super(BaseSectionMenuRelatedAdmin, self).save_model(
             request, obj, form, change,
         )
@@ -484,6 +492,8 @@ class PortalMenuAdmin(MenuAdmin):
         if not getattr(menu, self.related_field, None):
             basecontent = Menu.objects.get(slug=self.menu_slug or settings.MENU_PORTAL_SLUG)
             setattr(menu, self.related_field, basecontent)
+            if hasattr(menu._mptt_meta, 'update_mptt_cached_fields'):
+                menu._mptt_meta.update_mptt_cached_fields(menu)
         return menu
 
 
