@@ -166,24 +166,24 @@ class Menu(models.Model):
             return ('merengue.base.views.admin_link', [menu_content_type.id, self.id, ''])
 
     @permalink
-    def menu_public_link_with_out_section(self, ancestors_path):
-        return self._menu_public_link_without_section(self, ancestors_path)
+    def menu_public_link_without_section(self, ancestors_path):
+        return self._menu_public_link_without_section(ancestors_path)
 
     def _menu_public_link_without_section(self, ancestors_path):
         return ('menu_view', (ancestors_path, self.slug))
 
-    @permalink
     def public_link(self):
         menus_ancestors = [menu.slug for menu in self.get_ancestors()][1:]  # first is a dummy root menu and we discard it
         ancestors_path = menus_ancestors and '/%s' % '/'.join(menus_ancestors) or ''
         section = self.get_section()
         if section:
-            return section.get_real_instance()._menu_public_link(ancestors_path, self)
+            return section.get_real_instance().menu_public_link(ancestors_path, self)
         else:
-            return self._menu_public_link_without_section(ancestors_path)
+            return self.menu_public_link_without_section(ancestors_path)
 
     def update_url(self, commit=True):
         try:
+            _menu_sections_cache.reload_if_dirty()
             self.url = self.public_link()
         except BaseLink.DoesNotExist:
             self.url = ''
@@ -442,15 +442,20 @@ class BaseSection(BaseContent):
     def breadcrumbs_items(self):
         return [(unicode(self), self.get_absolute_url())]
 
-    def breadcrumbs(self, content=None):
+    def breadcrumbs(self, content=None, context=None):
         urls = self.breadcrumbs_items()
         if content:
             urls.append((unicode(content), ''))
-        return render_to_string('section/breadcrumbs.html', {'urls': urls})
+        context = context or {}
+        context.update({'urls': urls})
+        return render_to_string('section/breadcrumbs.html', context)
 
     def url_in_section(self, url):
         return url
 
+    def body_classes(self):
+        return []
+
 
 def strip_section_prefix(link):
     section_index_url = reverse('section_index')[:-1]
@@ -644,6 +649,7 @@ post_save.connect(handle_link_url_post_save)
 def handle_menu_url_post_save(sender, instance, **kwargs):
     url = instance.url
     instance.update_url(commit=False)
+    _menu_sections_cache.clear()
     if instance and url != instance.url:
         instance.save()
 
