@@ -21,6 +21,10 @@ ugettext = lambda s: s  # dummy ugettext function, as said on django docs
 
 MERENGUEDIR = path.dirname(path.abspath(__file__))
 
+#This line is usefull when you copy your server data base for develop in your
+#local machine but you do not copy all content images (used in DEBUG mode only)
+PUBLIC_SERVER = None
+
 # List  of  callables that know how to import templates from various sources.
 TEMPLATE_LOADERS = (
     #('django.template.loaders.cached.Loader', (
@@ -37,6 +41,7 @@ TEMPLATE_CONTEXT_PROCESSORS = (
     'django.core.context_processors.i18n',
     'django.core.context_processors.media',
     'django.core.context_processors.request',
+    'django.contrib.messages.context_processors.messages',
     'merengue.context_processors.all_context',
     'merengue.theming.context_processors.media',
     'merengue.section.context_processors.section',
@@ -81,6 +86,7 @@ INSTALLED_APPS = (
     'django.contrib.sessions',
     'django.contrib.sites',
     'django.contrib.admin',
+    'django.contrib.messages',
     #'django.contrib.comments',
     'django_extensions',
     'template_utils',
@@ -110,10 +116,12 @@ INSTALLED_APPS = (
     'notification',
     'compressor',
     'announcements',
+    'django_su',
 ) + MERENGUE_APPS
 
 # Merengue specific middlewares.
 MERENGUE_MIDDLEWARE_CLASSES = (
+    'merengue.pluggable.middleware.ActivePluginsMiddleware',
     'merengue.middleware.RemoveRandomAjaxParameter',
     'merengue.section.middleware.RequestSectionMiddleware',
     'merengue.section.middleware.DebugSectionMiddleware',
@@ -121,7 +129,6 @@ MERENGUE_MIDDLEWARE_CLASSES = (
     'merengue.middleware.SimplifiedLayoutMiddleware',
     'merengue.middleware.LocaleMiddleware',
     'merengue.middleware.HttpStatusCodeRendererMiddleware',
-    'merengue.pluggable.middleware.ActivePluginsMiddleware',
     'django.middleware.csrf.CsrfResponseMiddleware',
 )
 
@@ -180,6 +187,9 @@ DETECT_BROKEN_PLUGINS = True
 # The module to store session data
 SESSION_ENGINE = 'merengue.backends.db'
 
+# Admin only pure basesection objects under /admin/section/basesection/
+ADMIN_PURE_SECTIONS = True
+
 # Roles which may be acquired by an user when visiting a content inside a section
 ACQUIRE_SECTION_ROLES = False
 
@@ -261,6 +271,7 @@ AJAX_LOOKUP_CHANNELS = {
     'perms_group': ('merengue.perms.lookups', 'GroupLookup'),
     'base_content': ('merengue.base.lookups', 'ContentLookup'),
     'user': ('merengue.base.lookups', 'UserLookup'),
+    'django_su': ('merengue.base.lookups', 'UserLookup'),
     'section_contentlink': ('merengue.section.lookups', 'ContentLinkLookup'),
 }
 
@@ -268,6 +279,7 @@ JQUERY_BASE_MEDIA = 'merengue/js/'
 
 # Customization Comment app for merengue, feedback
 # COMMENTS_APP = 'plugins.feedback'
+CONTENT_COMMENTABLE_BY_DEFAULT = 'allowed'
 
 MENU_PORTAL_SLUG = 'portal_menu'
 
@@ -283,6 +295,9 @@ SERIALIZATION_MODULES = {
     "xml": "merengue.xml_serializer",
 }
 
+# Prefix for all project
+BASE_URL = '/'
+
 # Prefix for all merengue URLs
 MERENGUE_URLS_PREFIX = 'cms'
 
@@ -290,7 +305,7 @@ MERENGUE_URLS_PREFIX = 'cms'
 LOGIN_URL = '/%s/login/' % MERENGUE_URLS_PREFIX
 LOGOUT_URL = '/%s/logout/' % MERENGUE_URLS_PREFIX
 LOGIN_REDIRECT_URL = '/'
-LOGOUT_REDIRECT_URL = None
+LOGOUT_REDIRECT_URL = LOGIN_REDIRECT_URL
 
 # Test settings
 TEST_RUNNER = 'merengue.test.run_tests'
