@@ -18,9 +18,11 @@
 from django.conf import settings
 from django.template.loader import render_to_string
 
-from inplaceeditform.fields import AdaptorTextAreaField
+from inplaceeditform.fields import AdaptorTextAreaField, AdaptorImageField
 from cmsutils.forms.widgets import TinyMCE
 
+from merengue.base.models import BaseContent, BaseCategory
+from merengue.section.models import Menu
 from merengue.perms.utils import has_permission
 
 
@@ -30,21 +32,36 @@ class AdaptorEditInline(object):
     def can_edit(cls, field):
         request = field.request
         obj = field.obj
+        can_edit = False
+        edit_permission = 'edit'
         if request.user.is_anonymous():
-            can_edit = False
+            pass
         elif request.user.is_superuser:
             can_edit = True
         else:
             if not getattr(request, 'cache_edit_inline', None):
                 request.cache_edit_inline = {}
+            if not isinstance(obj, BaseContent):
+                if isinstance(obj, BaseCategory):
+                    edit_permission = 'manage_category'
+                if isinstance(obj, Menu):
+                    obj = obj.get_section()
+                else:
+                    obj = None
             if obj in request.cache_edit_inline:
                 can_edit = request.cache_edit_inline.get(obj)
             else:
-                can_edit = has_permission(obj, request.user, 'edit')
-                request.cache_edit_inline[obj] = can_edit
+                can_edit = has_permission(obj, request.user, edit_permission)
+            request.cache_edit_inline[obj] = can_edit
         return can_edit
 
 
+class AdaptorImageThumbnailField(AdaptorImageField):
+
+    def render_value(self, field_name=None, template_name='adaptor_imagethumbnail/render_value.html'):
+        return super(AdaptorImageThumbnailField, self).render_value(field_name=field_name, template_name=template_name)
+
+
 class AdaptorTinyMCEField(AdaptorTextAreaField):
 
     @property
@@ -74,6 +91,10 @@ class AdaptorTinyMCEField(AdaptorTextAreaField):
 
         extra_mce_settings = getattr(settings, 'EXTRA_MCE', {})
         extra_mce_settings.update(self._order_tinymce_buttons(tiny_mce_buttons, tiny_mce_selectors))
+        content_css = [i for i in settings.TINYMCE_EXTRA_MEDIA.get('css', [])]
+        content_js = [i for i in settings.TINYMCE_EXTRA_MEDIA.get('css', [])]
+        content_css.extend(["merengue/css/editorstyles.css"])
+        content_css = ','.join(["%s%s" % (settings.MEDIA_URL, css) for css in content_css])
         extra_mce_settings.update({'inplace_edit': True,
                               'theme_advanced_blockformats': 'h1,h2,h4,blockquote',
                               'file_browser_callback': 'CustomFileBrowser',
@@ -81,6 +102,8 @@ class AdaptorTinyMCEField(AdaptorTextAreaField):
                               'theme_advanced_resizing': True,
                               'theme_advanced_resize_horizontal': True,
                               'convert_on_click': True,
+                              'content_css': content_css,
+                              'content_js': content_js,
                              })
         extra_mce_settings.update(self.widget_options)
         field.field.widget = TinyMCE(extra_mce_settings=extra_mce_settings,
