@@ -15,23 +15,21 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with Merengue.  If not, see <http://www.gnu.org/licenses/>.
 
+import csv
 import ConfigParser
 import os
 import zipfile
+from datetime import datetime
 from cStringIO import StringIO
 
 from django.conf import settings
-from django.core.cache import cache
-from django.utils.cache import _generate_cache_header_key
-from django.utils.encoding import smart_str
-
-from django.core.management.base import CommandError
-
 from django.core import serializers
 from django.core.management.color import no_style
+from django.core.management.base import CommandError
 from django.db import connection, transaction
 from django.db.models import get_models
 from django.db.models.loading import load_app
+from django.utils.encoding import smart_str
 
 
 class classproperty(property):
@@ -54,19 +52,6 @@ def copy_request(request, delete_list, copy=None):
     return request_copy
 
 
-def invalidate_cache_for_path(request_path):
-    """ invalidates cache based on request.path """
-    # wrap a dummy request object for call django function
-
-    class Request(object):
-        pass
-
-    request = Request()
-    request.path = request_path
-    cache_header_key = _generate_cache_header_key(settings.CACHE_MIDDLEWARE_KEY_PREFIX, request)
-    cache.delete(cache_header_key)
-
-
 def save_config(overwrite=True, save_all=True):
     from merengue.registry import RegisteredItem
     from merengue.action.models import RegisteredAction
@@ -111,7 +96,7 @@ def add_models(zip_config, models_to_save):
         model = model_to_save[0]
         file_name = model_to_save[1]
         fixtures = get_fixtures(model)
-        format = 'json'
+        format = 'xml'
         fixtures_file = "%s.%s" % (file_name, format)
         zip_config.writestr(fixtures_file, "\n".join(fixtures))
 
@@ -174,12 +159,12 @@ def add_fixtures(zip_config, plugin, plugin_path, plugin_path_zip):
     plugin_mod = load_app(plugin_modname)
     plugin_models = get_models(plugin_mod)
     fixtures = get_fixtures(plugin_models)
-    format = 'json'
+    format = 'xml'
     fixtures_file = os.path.join(plugin_path_zip, "fixtures.%s" % format)
     zip_config.writestr(fixtures_file, "\n".join(fixtures))
 
 
-def get_fixtures(model_or_models, format='json'):
+def get_fixtures(model_or_models, format='xml'):
     data = []
     format = format.lower()
     if not isinstance(model_or_models, (list, tuple)):
@@ -208,7 +193,7 @@ def add_folder(zip_config, path_root, path_zip):
                 dirnames.remove(dirname)
         for filename in filenames:
             # Exclude compiled, hidden and temporal files
-            if not (filename.endswith(".pyc") or dirname.endswith("~") or
+            if not (filename.endswith(".pyc") or filename.endswith("~") or
                 filename.startswith(".")):
                 file_path = os.path.join(dirpath, filename)
                 dir_path = dirpath.replace(path_root, path_zip)
@@ -221,6 +206,7 @@ def restore_config(zip_config):
     from merengue.block.models import RegisteredBlock
     from merengue.registry import RegisteredItem
     from merengue.pluggable.models import RegisteredPlugin
+    from merengue.pluggable.utils import install_plugin
     from merengue.theming.models import Theme
     config = get_config(zip_config)
     restore_all = (config.get("mode", "fixtures") == "all")
@@ -239,6 +225,8 @@ def restore_config(zip_config):
     if restore_all:
         # TODO: Implement "all" mode restore
         pass
+    for plugin in RegisteredPlugin.objects.filter(installed=True):
+        install_plugin(plugin)
     zip_config.close()
     print 'File restored successfully'
 
@@ -268,7 +256,7 @@ def restore_models(zip_config, models_to_restore):
         models = set()
         for model_to_restore, file_name in models_to_restore:
             model_to_restore.objects.all().delete()  # we first delete all objects to avoid duplication problems
-            format = 'json'
+            format = 'xml'
             fixtures_file_name = "%s.%s" % (file_name, format)
             fixtures_data = zip_config.read(fixtures_file_name)
             fixtures = serializers.deserialize(format, fixtures_data)
@@ -276,16 +264,15 @@ def restore_models(zip_config, models_to_restore):
             for fixture in fixtures:
                 if fixture:
                     has_objects = True
-                fixture.save()
+                    fixture.save()
                 models.add(fixture.object.__class__)
         # HACK: If we found even one object in a fixture, we need to reset
         # the database sequences.
         if has_objects:
             sequence_reset_sql(models)
-    except Exception, e:
+    except:
         transaction.savepoint_rollback(sid)
-        raise CommandError("Unable to restore models from fixtures: %s" \
-                               % e)
+        raise
     else:
         transaction.savepoint_commit(sid)
 
@@ -322,24 +309,6 @@ def get_all_parents(model, parents=None):
     return parents
 
 
-def invalidate_johnny_cache(model, invalidate_parent=False, parent_finish=None):
-    if 'johnny' in settings.INSTALLED_APPS:
-        from johnny import cache
-        from django.core.cache import cache as django_cache
-        query_cache_backend = cache.get_backend()(django_cache)
-        query_cache_backend.patch()
-        if parent_finish and not issubclass(model, parent_finish):
-            return
-        cache.invalidate(model._meta.db_table)
-        if not invalidate_parent:
-            return
-
-        for model_parent in model.__bases__:
-            if parent_finish and not issubclass(model, parent_finish):
-                continue
-            invalidate_johnny_cache(model_parent, invalidate_parent, parent_finish)
-
-
 def is_last_application(app):
     """ returns Merengue last application """
     last_app = settings.MERENGUE_APPS[-1].split('.')[1]
@@ -356,3 +325,14 @@ def ask_yesno_question(question, default_answer):
             return answer == 'yes' and True or False
         else:
             print 'Please answer yes or no'
+
+
+def print_sql_queries(base_path):
+    now = datetime.now()
+    file_name = 'sqls_%s%s.csv' % (now.strftime('%Y%m%d%H%M%S'), str(now.microsecond))
+    fout = open(os.path.join(base_path, file_name), 'w')
+    csv_stream = csv.writer(fout, delimiter=',',
+                            quotechar='"', quoting=csv.QUOTE_MINIMAL)
+    for query in connection.queries:
+        csv_stream.writerow([query['sql'], query['time']])
+    fout.close()
