@@ -7,17 +7,36 @@ from django.core.serializers import base, xml_serializer
 from django.db import models
 from django.db.models.fields import FieldDoesNotExist
 
-from transmeta import get_field_language
+from transmeta import get_fallback_fieldname, get_real_fieldname, get_field_language, get_all_translatable_fields
+
+from merengue.base.dbfields import JSONField
+from merengue.base.models import BaseContent
 
 
 class Serializer(xml_serializer.Serializer):
     """
     Serializes a QuerySet to XML.
     """
-
     pass
 
 
+class DeserializedObject(base.DeserializedObject):
+    """
+    A deserialized model.
+
+    Extends the base deserialized object for asigning permission if object is
+    the object is a BaseContent instance
+    """
+
+    def save(self, save_m2m=True, using=None):
+        super(DeserializedObject, self).save(save_m2m, using)
+        if isinstance(self.object, BaseContent):
+            # it is a weird hack but we cannot update the object permission
+            # because the superclass save function is save_base with raw=True
+            # and the signals are not emited
+            self.object.populate_workflow_status(force_update=True, raw=True)
+
+
 class Deserializer(xml_serializer.Deserializer):
     """
     Deserialize XML.
@@ -109,5 +128,22 @@ class Deserializer(xml_serializer.Deserializer):
                     value = field.to_python(xml_serializer.getInnerText(field_node).strip())
                 data[field.name] = value
 
+        # check there is not any mandatory translatable fields in the fixtures without
+        # a value in the fallback language. In that case use the english language.
+        # This is to make the initial fixtures work in languages not included by default
+        # in fixtures
+        for trans_field in get_all_translatable_fields(Model):
+            fallback_fieldname = get_fallback_fieldname(trans_field)
+            if Model._meta.get_field(fallback_fieldname).null:
+                continue  # not a mandatory field
+            en_fieldname = get_real_fieldname(trans_field, 'en')
+            if data.get(fallback_fieldname, None) is None and data.get(en_fieldname, None) is not None:
+                data[fallback_fieldname] = data[en_fieldname]
+
+        obj = Model(**data)
+        for field in obj._meta.local_fields:
+            if isinstance(field, JSONField):
+                field_name = field.name
+                setattr(obj, field_name, getattr(obj, 'get_%s_json' % field_name)())
         # Return a DeserializedObject so that the m2m data has a place to live.
-        return base.DeserializedObject(Model(**data), m2m_data)
+        return DeserializedObject(obj, m2m_data)
