@@ -18,9 +18,9 @@
 from merengue.collection.utils import create_normalize_collection
 from merengue.pluggable import Plugin
 
-from plugins.banner.admin import BannerAdmin, BannerSectionAdmin
-from plugins.banner.blocks import BannerBlock
-from plugins.banner.models import Banner
+from plugins.banner.admin import BannerAdmin, BannerCategoryAdmin, BannerSectionAdmin
+from plugins.banner.blocks import BannerBlock, PortletBannerBlock, CategorizedBannerBlock
+from plugins.banner.models import Banner, BannerCategory
 from plugins.banner.viewlets import AllBannerViewlet
 
 
@@ -36,11 +36,12 @@ class PluginConfig(Plugin):
     def section_models(self):
         return [(Banner, BannerSectionAdmin)]
 
-    def get_model_admins(self):
-        return [(Banner, BannerAdmin), ]
+    def models(self):
+        return [(Banner, BannerAdmin),
+                (BannerCategory, BannerCategoryAdmin)]
 
     def get_blocks(self):
-        return [BannerBlock]
+        return [BannerBlock, PortletBannerBlock, CategorizedBannerBlock]
 
     def get_viewlets(self):
         return [AllBannerViewlet]
