@@ -103,7 +103,7 @@ class ContactForm(models.Model):
         verbose_name = _('Contact Form')
         verbose_name_plural = _('Contact Forms')
 
-    def get_form(self, request):
+    def get_form(self, request, prefix=''):
         from plugins.contactform.forms import ContactFormForm
         from django import forms
         from django.utils.translation import ugettext as _
@@ -119,14 +119,20 @@ class ContactForm(models.Model):
         }
 
         if request.method == 'POST':
-            f = ContactFormForm(request.POST, request.FILES)
+            if request.POST.get('%scontactform_id_%s' % (prefix, self.id), None) == str(self.id):
+                f = ContactFormForm(request.POST, request.FILES)
+            else:
+                f = ContactFormForm(initial=request.POST)
         else:
             f = ContactFormForm(initial=request.GET)
         index = 0
 
+        f.fields.insert(index, '%scontactform_id_%s' % (prefix, self.id), forms.CharField(widget=forms.HiddenInput, initial=self.id))
+        index += 1
+
         if self.sender_email:
             if request.user.is_authenticated():
-                sender_email = forms.EmailField(label=_('sender email'),
+                sender_email = forms.EmailField(label=_('Sender email'),
                                                 initial=request.user.email)
                 if not self.is_sender_email_editable:
                     attrs = sender_email.widget.attrs or {}
@@ -134,7 +140,7 @@ class ContactForm(models.Model):
                     editable_attrs.update(attrs)
                     sender_email.widget.attrs = editable_attrs
             else:
-                sender_email = forms.EmailField(label=_('sender email'))
+                sender_email = forms.EmailField(label=_('Sender email'))
             f.fields.insert(index, 'sender_email', sender_email)
             index += 1
 
@@ -160,7 +166,8 @@ class ContactForm(models.Model):
                               help_text=help_text,
                               required=opt.required)
 
-            f.fields.insert(index, 'option_%s' % opt.id, field)
+            name = opt.name or 'option_%s' % opt.id
+            f.fields.insert(index, name, field)
 
             index += 1
 
@@ -179,6 +186,7 @@ class ContactFormOpt(models.Model):
     __metaclass__ = TransMeta
 
     label = models.CharField(verbose_name=_('label'), max_length=200)
+    name = models.CharField(verbose_name=_('name'), max_length=200, blank=True, null=True)
     field_type = models.CharField(verbose_name=_('type'), max_length=20,
                                 choices=FIELD_TYPE_CHOICES)
     help_text = models.TextField(verbose_name=_('help text'), blank=True)
