@@ -19,7 +19,7 @@
 from django.http import HttpResponseRedirect
 from django.shortcuts import get_object_or_404
 
-from cmsutils.log import send_info
+from merengue.base.log import send_info
 from merengue.base.models import BaseContent
 from plugins.contactform.models import ContactForm
 
@@ -33,6 +33,8 @@ def contact_form_submit(request, content_id, contact_form_id):
         form = contact_form.get_form(request)
         if form.is_valid():
             sentcontactform = form.save(request, content, contact_form)
+            if not sentcontactform:
+                return errors_to_session(request, content, form, contact_form_id)
             if contact_form.redirect_to:
                 redirect = contact_form.redirect_to
                 if contact_form.redirect_to_with_params:
@@ -60,4 +62,5 @@ def errors_to_session(request, content, form, contact_form_id):
     request.session['form_data_%s' % contact_form_id] = form.data
     redirect = request.META.get('HTTP_REFERER',
                                 content.public_link())
+    redirect = '%s?e=1' % redirect
     return HttpResponseRedirect(redirect)
