@@ -37,13 +37,17 @@ class ContentGroupLinksBlock(Block):
         'vary_on_language': True,
     }
 
+    @classmethod
+    def get_models_refresh_cache(self):
+        return [ContentGroup]
+
     def render(self, request, place, context, *args, **kwargs):
         content_groups = ContentGroup.objects.filter(contents=context['content'])
         if content_groups:
             filtered_contents = []
             filtered_contents_len = 0
             for cont in content_groups:
-                for child_cont in cont.contents.all():
+                for child_cont in cont.contents.order_by('contentgroupcontent__order'):
                     item = (child_cont.name, child_cont.get_absolute_url())
                     if not item in filtered_contents:
                         filtered_contents_len += 1
