@@ -15,44 +15,65 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with Merengue.  If not, see <http://www.gnu.org/licenses/>.
 
+from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.utils.translation import ugettext_lazy as _
 
 from merengue.pluggable import Plugin
 from merengue.registry import params
-from merengue.section.admin import DocumentRelatedModelAdmin
+from merengue.multimedia.admin import PhotoAdmin, VideoAdmin, AudioAdmin
+from merengue.multimedia.models import Photo, Video, Audio
+from merengue.section.admin import DocumentRelatedModelAdmin, DocumentAdmin
 from merengue.section.models import Document
 
-from plugins.core.actions import AdminAction, LoginAction, LogoutAction, PrintAction
+from plugins.core.actions import AdminAction, LoginAction, LogoutAction, PrintAction, HotLinkAction
+from plugins.core.admin import CustomMetaAdmin
 from plugins.core.blocks import (CoreMenuBlock, NavigationBlock,
-                                 PrimaryLinksBlock, SecondaryLinksBlock,
                                  PortalMenuBlock, ContactInfoBlock,
-                                 AnnouncementsBlock)
-from plugins.core.panels import InplaceEditPanel, InlineTransPanel, VersionPanel
+                                 AnnouncementsBlock, PortalLinksBlock)
+from plugins.core.models import CustomMeta
+from plugins.core.panels import (InplaceEditPanel, InlineTransPanel, VersionPanel,
+                                 InvalidateCachePanel, AddBlockPanel)
 
 
 class PluginConfig(Plugin):
     name = 'Core'
     description = 'Core plugin'
     version = '0.0.1a'
+    model_admins = [
+        (CustomMeta, CustomMetaAdmin),
+        (Document, DocumentAdmin),
+        (Photo, PhotoAdmin),
+        (Video, VideoAdmin),
+        (Audio, AudioAdmin),
+    ]
 
     url_prefixes = (
+        ('core', 'plugins.core.urls'),
     )
 
     config_params = [
         params.Content(name='home_initial_content',
-                       label=_('home initial content'), default=1)]
+                       label=_('home initial content'), default=1),
+        params.Single(name='login_url',
+                       label=_('Login URL'), default=settings.LOGIN_URL)]
 
     def get_actions(self):
-        return [AdminAction, LoginAction, LogoutAction, PrintAction]
+        return [AdminAction, LoginAction, LogoutAction, PrintAction, HotLinkAction]
 
     def get_blocks(self):
-        return [CoreMenuBlock, NavigationBlock, PrimaryLinksBlock,
-                SecondaryLinksBlock, PortalMenuBlock, ContactInfoBlock,
-                AnnouncementsBlock]
+        return [CoreMenuBlock, NavigationBlock, PortalMenuBlock,
+                ContactInfoBlock, AnnouncementsBlock, PortalLinksBlock]
 
     def get_toolbar_panels(self):
-        return [InplaceEditPanel, InlineTransPanel, VersionPanel]
+        return [InplaceEditPanel, InlineTransPanel, AddBlockPanel,
+                InvalidateCachePanel, VersionPanel, ]
+
+    def models(self):
+        return self.model_admins
+
+    def get_model_admins(self):
+        return self.model_admins
 
     def section_models(self):
         return [(Document, DocumentRelatedModelAdmin)]
