@@ -1,4 +1,4 @@
-# Copyright (c) 2010 by Yaco Sistemas <msaelices@yaco.es>
+# Copyright (c) 2010 by Yaco Sistemas
 #
 # This file is part of Merengue.
 #
@@ -26,8 +26,8 @@ from merengue.action.actions import ContentAction
 class FacebookLink(ContentAction):
     name = 'facebooklink'
     verbose_name = _('Share in Facebook')
+    help_text = _('Facebook share widget')
 
-    @classmethod
-    def get_response(cls, request, content):
+    def get_response(self, request, content):
         request_url = 'http://%s%s' % (Site.objects.get_current().domain, content.public_link())
         return HttpResponseRedirect('http://www.facebook.com/share.php?u=%s' % urlquote(request_url))
