@@ -1,3 +1,4 @@
+import unicodedata
 import mimetypes
 from os.path import join, isdir, isfile
 from django.http import HttpResponseRedirect, HttpResponse
@@ -5,20 +6,37 @@ from django.shortcuts import render_to_response, Http404, get_object_or_404
 from django.template import RequestContext
 from django.utils import simplejson
 from django.utils.translation import ugettext as _
+from django.utils.encoding import force_unicode
 
 from merengue.base.decorators import login_required_or_permission_denied
+from merengue.base.views import content_list
+from merengue.section.utils import get_section
 
 from plugins.filebrowser.forms import EditDocForm, AddDocForm
 from plugins.filebrowser.models import Repository, Document, FileDocument, ImageDocument
 from plugins.filebrowser.templatetags.filebrowser_tags import filebrowser_reverse
 
-from cmsutils.log import send_info, send_error
-from cmsutils.resourcemanager import require_resources
+from merengue.base.log import send_info, send_error
 
 
 FILEBROWSER_BASE_TEMPLATE = 'base.html'
 
 
+@login_required_or_permission_denied
+def repositories(request, extra_context=None):
+    filters = {}
+    section = get_section(request, extra_context)
+    if section:
+        filters['section'] = section
+    repository_list = Repository.objects.filter(**filters)
+    context = {'base_template': 'content_list.html'}
+    extra_context = extra_context or {}
+    context.update(extra_context)
+    return content_list(request, repository_list,
+                        extra_context=context,
+                        template_name='filebrowser/repository_list.html')
+
+
 @login_required_or_permission_denied
 def root(request, repository_name,
          base_template=FILEBROWSER_BASE_TEMPLATE, url_prefix=None):
@@ -41,7 +59,7 @@ def listing(request, repository_name, path='',
     documents = Document.objects.filter(repository=repository,
                                         location=location)
 
-    edit_permission = request.user.is_superuser
+    edit_permission = request.user.is_staff
 
     return render_to_response('filebrowser/listing.html',
                               {'repository': repository,
@@ -55,7 +73,7 @@ def listing(request, repository_name, path='',
                                'documents': documents,
                                'url_prefix': url_prefix,
                                'edit_permission': edit_permission},
-                              context_instance = RequestContext(request))
+                              context_instance=RequestContext(request))
 
 
 @login_required_or_permission_denied
@@ -70,7 +88,7 @@ def createdir(request, repository_name, path='',
             errornote = _('You must introduce the name of the new folder')
         elif repository.check_dir(join(path, dirname)):
             errornote = _(u'Folder %(dirname)s already exists') % {'dirname': dirname}
-        if errornote: # si hay algun tipo de error
+        if errornote:  # si hay algun tipo de error
             return render_to_response('filebrowser/createdir.html',
                                       {'repository': repository,
                                        'base_template': base_template,
@@ -80,8 +98,8 @@ def createdir(request, repository_name, path='',
                                       context_instance=RequestContext(request))
         repository.create_dir(join(path, dirname))
         message = _('Folder created successfully')
-        request.user.message_set.create(message=message)
-        return HttpResponseRedirect(filebrowser_reverse("filebrowser_dir_listing",
+        send_info(request, message)
+        return HttpResponseRedirect(filebrowser_reverse(request, "filebrowser_dir_listing",
                         kwargs={'repository_name': repository.name,
                                 'path': path},
                         url_prefix=url_prefix))
@@ -93,7 +111,7 @@ def createdir(request, repository_name, path='',
                                    'path': path,
                                    'parents': parents,
                                    'url_prefix': url_prefix},
-                                  context_instance = RequestContext(request))
+                                  context_instance=RequestContext(request))
 
 
 @login_required_or_permission_denied
@@ -103,12 +121,13 @@ def upload(request, repository_name, path='',
     if request.method == 'POST':
         for k, f in request.FILES.items():
             if k.startswith('file_'):
-                fout = repository.create_file(join(path, f.name))
+                file_name = unicodedata.normalize('NFKD', force_unicode(f.name)).encode('ascii', 'ignore')
+                fout = repository.create_file(join(path, file_name))
                 for chunk in f.chunks():
                     fout.write(chunk)
                 fout.close()
         send_info(request, _('Files uploaded successfully'))
-        return HttpResponseRedirect(filebrowser_reverse("filebrowser_dir_listing",
+        return HttpResponseRedirect(filebrowser_reverse(request, "filebrowser_dir_listing",
                         kwargs={'repository_name': repository.name,
                                 'path': path},
                         url_prefix=url_prefix))
@@ -120,7 +139,7 @@ def upload(request, repository_name, path='',
                                    'path': path,
                                    'parents': parents,
                                    'url_prefix': url_prefix},
-                                  context_instance = RequestContext(request))
+                                  context_instance=RequestContext(request))
 
 
 @login_required_or_permission_denied
@@ -172,7 +191,7 @@ def action(request, repository_name, path,
                     old_elems.append(request.POST['olddoc_%s' % k[len('doc_'):]])
     if not elems:
         send_error(request, _("You didn't selected any element"))
-        return HttpResponseRedirect(filebrowser_reverse("filebrowser_dir_listing",
+        return HttpResponseRedirect(filebrowser_reverse(request, "filebrowser_dir_listing",
                         kwargs={'repository_name': repository.name,
                                 'path': path},
                         url_prefix=url_prefix))
@@ -205,18 +224,18 @@ def action(request, repository_name, path,
                                    'docs': docs,
                                    'url_prefix': url_prefix,
                                   },
-                                  context_instance = RequestContext(request))
+                                  context_instance=RequestContext(request))
     elif action == 'rename':
         repository.rename_elems(path, elems, old_elems)
-        request.user.message_set.create(message=_('Elements renamed successfully'))
-        return HttpResponseRedirect(filebrowser_reverse("filebrowser_dir_listing",
+        send_info(request, _('Elements renamed successfully'))
+        return HttpResponseRedirect(filebrowser_reverse(request, "filebrowser_dir_listing",
                         kwargs={'repository_name': repository.name,
                                 'path': path},
                         url_prefix=url_prefix))
     elif action == 'delete':
         repository.delete_elems(path, elems)
-        request.user.message_set.create(message=_('Elements deleted successfully'))
-        return HttpResponseRedirect(filebrowser_reverse("filebrowser_dir_listing",
+        send_info(request, _('Elements deleted successfully'))
+        return HttpResponseRedirect(filebrowser_reverse(request, "filebrowser_dir_listing",
                         kwargs={'repository_name': repository.name,
                                 'path': path},
                         url_prefix=url_prefix))
@@ -250,46 +269,40 @@ def editdoc(request, repository_name, doc_slug,
                     doc_slug=doc_slug, parents=parents, url_prefix=url_prefix)
 
 
-@require_resources('js/jquery-1.2.6.pack.js', 'js/manage-attachments-docs.js',
-                   'js/jquery.form.js')
 @login_required_or_permission_denied
 def viewdoc(request, repository_name, doc_slug,
             base_template=FILEBROWSER_BASE_TEMPLATE, url_prefix=None):
-    if repository_name=='documents':
-        repository = get_object_or_404(Repository, name=repository_name)
-        document = get_object_or_404(Document, repository=repository,
-                                     slug=doc_slug)
-        file_field = None
-        if request.method == 'POST':
-            if 'addfile' in request.POST:
-                file_field = 'file'
-                model_class = FileDocument
-            elif 'addimage' in request.POST:
-                file_field = 'image'
-                model_class = ImageDocument
+    repository = get_object_or_404(Repository, name=repository_name)
+    document = get_object_or_404(Document, repository=repository,
+                                    slug=doc_slug)
+    file_field = None
+    if request.method == 'POST':
+        if 'addfile' in request.POST:
+            file_field = 'file'
+            model_class = FileDocument
+        elif 'addimage' in request.POST:
+            file_field = 'image'
+            model_class = ImageDocument
 
-        if file_field and file_field in request.FILES:
-            file = request.FILES[file_field]
-            instance = model_class()
-            instance.document = document
-            instance.file.save(file.name, file)
+    if file_field and file_field in request.FILES:
+        file = request.FILES[file_field]
+        instance = model_class()
+        instance.document = document
+        instance.file.save(file.name, file)
 
-        files = FileDocument.objects.filter(document=document)
-        images = ImageDocument.objects.filter(document=document)
-        parents = document.get_parents()
+    files = FileDocument.objects.filter(document=document)
+    images = ImageDocument.objects.filter(document=document)
+    parents = document.get_parents()
 
-        return render_to_response('filebrowser/document.html',
-                                  {'repository': repository,
-                                   'base_template': base_template,
-                                   'parents': parents,
-                                   'document': document,
-                                   'doc_files': files,
-                                   'doc_images': images,
-                                   'url_prefix': url_prefix},
-                                  context_instance = RequestContext(request))
-    else:
-        send_error(request, _("You don't have permission to do that."))
-        return HttpResponseRedirect('/')
+    return render_to_response('filebrowser/document.html',
+                                {'repository': repository,
+                                'base_template': base_template,
+                                'parents': parents,
+                                'document': document,
+                                'doc_files': files,
+                                'doc_images': images,
+                                'url_prefix': url_prefix},
+                                context_instance=RequestContext(request))
 
 
 @login_required_or_permission_denied
