@@ -15,10 +15,12 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with Merengue.  If not, see <http://www.gnu.org/licenses/>.
 
+from merengue.urlresolvers import get_url_default_lang
 from merengue.pluggable import Plugin
 
 from plugins.microsite.models import MicroSite
 from plugins.microsite.admin import MicroSiteAdmin
+from plugins.microsite.blocks import HighlightMenu
 
 
 class PluginConfig(Plugin):
@@ -27,9 +29,16 @@ class PluginConfig(Plugin):
     version = '0.0.1a'
 
     url_prefixes = (
-        ('microsite', 'plugins.microsite.urls'),
+        ({'en': 'microsite',
+          'es': 'micrositios'},
+             'plugins.microsite.urls'),
     )
 
-    @classmethod
-    def get_model_admins(cls):
+    def models(self):
         return [(MicroSite, MicroSiteAdmin)]
+
+    def get_section_prefixes(self):
+        return (u'/%s/' % self.url_prefixes[0][0][get_url_default_lang()], )
+
+    def get_blocks(self):
+        return [HighlightMenu]
