@@ -17,6 +17,10 @@
 
 from django.conf.urls.defaults import patterns, url
 
+PREFIX_DOC = 'info'
+
 urlpatterns = patterns('plugins.microsite.views',
     url(r'^(?P<microsite_slug>[\w-]+)/$', 'microsite_view', name='microsite_view'),
+    url(r'^(?P<microsite_slug>[\w-]+)/%s/(?P<doc_id>\d+)/(?P<doc_slug>[\w-]+)/$' % PREFIX_DOC, 'document_microsite_view', name='document_microsite_view'),
+    url(r'^(?P<microsite_slug>[\w-]+)/(?P<url>.*)$', 'microsite_url', name='microsite_url'),
 )
