@@ -18,9 +18,10 @@
 from django.utils.translation import ugettext
 from django.utils.translation import ugettext_lazy as _
 
-from merengue.block.blocks import Block
+from merengue.block.blocks import Block, BaseBlock
 from merengue.registry import params
 from merengue.registry.items import BlockQuerySetItemProvider
+from plugins.news.models import NewsItem, NewsCategory
 from plugins.news.views import get_news
 
 
@@ -30,7 +31,7 @@ class LatestNewsBlock(BlockQuerySetItemProvider, Block):
     help_text = _('Block with last news items published')
     default_place = 'leftsidebar'
 
-    config_params = BlockQuerySetItemProvider.config_params + [
+    config_params = BaseBlock.config_params + BlockQuerySetItemProvider.config_params + [
         params.PositiveInteger(
             name='limit',
             label=_('number of news for the "Latest news" block'),
@@ -38,13 +39,28 @@ class LatestNewsBlock(BlockQuerySetItemProvider, Block):
         ),
     ]
 
+    default_caching_params = {
+        'enabled': False,
+        'timeout': 3600,
+        'only_anonymous': True,
+        'vary_on_user': False,
+        'vary_on_url': True,
+        'vary_on_language': True,
+    }
+
+    @classmethod
+    def get_models_refresh_cache(self):
+        return [NewsItem, NewsCategory]
+
     def get_contents(self, request=None, context=None, section=None):
         news_list = get_news(request, filtering_section=False)
         return news_list
 
     def render(self, request, place, context, *args, **kwargs):
-        number_news = self.get_config().get('limit', []).get_value()
+        number_news = self.get_config().get('limit').get_value()
         news_list = self.get_queryset(request, context)[:number_news]
+        if self.get_config().get('filtering_section', False) and not news_list:
+            news_list = get_news(request, filtering_section=False)[:number_news]
         return self.render_block(request, template_name='news/block_latest.html',
                                  block_title=ugettext('Latest news'),
                                  context={'news_list': news_list})
