@@ -17,25 +17,23 @@
 
 from django.conf.urls.defaults import patterns, url
 
-from plugins.saml2.saml_config_loader import merengue_config_loader
 from plugins.saml2.saml_config_loader import get_attribute_mapping
 from plugins.saml2.saml_config_loader import get_create_unknown_user
 
 urlpatterns = patterns(
     'djangosaml2.views',
     url(r'^login/$', 'login', name='saml2_login',
-        kwargs=dict(config_loader=merengue_config_loader)),
+        kwargs=dict(config_loader_path='plugins.saml2.saml_config_loader.merengue_config_loader')),
     url(r'^acs/$', 'assertion_consumer_service', name='saml2_acs',
-        kwargs=dict(config_loader=merengue_config_loader,
-                    attribute_mapping=get_attribute_mapping,
-                    create_unknown_user=get_create_unknown_user)),
-    url(r'^logout/$', 'logout', name='saml2_logout',
-        kwargs=dict(config_loader=merengue_config_loader)),
+        kwargs=dict(config_loader_path='plugins.saml2.saml_config_loader.merengue_config_loader',
+                    attribute_mapping=get_attribute_mapping(),
+                    create_unknown_user=get_create_unknown_user())),
     url(r'^metadata/$', 'metadata', name='saml2_metadata',
-        kwargs=dict(config_loader=merengue_config_loader)),
+        kwargs=dict(config_loader_path='plugins.saml2.saml_config_loader.merengue_config_loader')),
     )
 
 urlpatterns += patterns(
     'plugins.saml2.views',
+    url(r'^logout/$', 'merengue_logout', name='saml2_logout'),
     url(r'^ls/$', 'merengue_logout_service', name='saml2_ls')
     )
