@@ -15,6 +15,8 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with Merengue.  If not, see <http://www.gnu.org/licenses/>.
 
+from django.utils.translation import ugettext_lazy as _
+
 from merengue.base.admin import PluginAdmin, RelatedModelAdmin
 from merengue.base.models import BaseContent
 
@@ -26,12 +28,17 @@ class VoteAdmin(PluginAdmin):
     form = VoteForm
 
 
-class VoteRelatedModelAdmin(VoteAdmin, RelatedModelAdmin):
+class VoteRelatedModelAdmin(RelatedModelAdmin, VoteAdmin):
     related_field = 'content'
+    tool_label = _('votes')
     one_to_one = True
 
 
 def register(site):
     """ Merengue admin registration callback """
-    site.register(Vote, VoteAdmin)
     site.register_related(Vote, VoteRelatedModelAdmin, related_to=BaseContent)
+
+
+def unregister(site):
+    """ Merengue admin unregistration callback """
+    site.unregister_related(Vote, VoteRelatedModelAdmin, related_to=BaseContent)
